@@ -35,8 +35,7 @@
 
 #include "totem-plugin-viewer-constants.h"
 
-#define TOTEM_COMPLEX_VERSION_BUILD "10.0"
-#define TOTEM_NARROWSPACE_VERSION   "7.2.0"
+#define TOTEM_NARROWSPACE_VERSION   "7.6.6"
 #define TOTEM_MULLY_VERSION         "1.4.0.233"
 #define TOTEM_CONE_VERSION          "0.8.6"
 #define TOTEM_GMP_VERSION_BUILD     "11.0.0.1024"
@@ -47,8 +46,29 @@ typedef struct {
   const char *mime_alias;
 } totemPluginMimeEntry;
 
+typedef enum {
+	TOTEM_QUEUE_TYPE_SET_VOLUME,
+	TOTEM_QUEUE_TYPE_CLEAR_PLAYLIST,
+	TOTEM_QUEUE_TYPE_ADD_ITEM,
+	TOTEM_QUEUE_TYPE_SET_BOOLEAN,
+	TOTEM_QUEUE_TYPE_SET_STRING
+} TotemQueueCommandType;
+
+typedef struct {
+	TotemQueueCommandType type;
+	union {
+		float volume;
+		struct {
+			char *uri;
+			char *title;
+			char *subtitle;
+		} add_item;
+		gboolean boolean;
+		char *string;
+	};
+} TotemQueueCommand;
+
 class totemBasicPlayer;
-class totemComplexPlayer;
 class totemConePlayer;
 class totemGMPControls;
 class totemGMPError;
@@ -137,10 +157,14 @@ class totemPlugin {
     static void ViewerOpenStreamCallback (DBusGProxy *aProxy,
 						      DBusGProxyCall *aCall,
 						      void *aData);
+    static void ViewerSetupStreamCallback (DBusGProxy *aProxy,
+						      DBusGProxyCall *aCall,
+						      void *aData);
     static void ViewerOpenURICallback (DBusGProxy *aProxy,
 						   DBusGProxyCall *aCall,
 						   void *aData);
 
+
     NPError ViewerFork ();
     void ViewerSetup ();
     void ViewerSetWindow ();
@@ -190,6 +214,7 @@ class totemPlugin {
 
     char* mMimeType;
 
+    char* mDocumentURI;
     char* mBaseURI;
     char* mSrcURI; /* relative to mBaseURI */
     char* mRequestBaseURI;
@@ -254,9 +279,12 @@ class totemPlugin {
     uint32_t mDuration;
     uint32_t mTime;
 
+    GQueue *mQueue;
+
 #ifdef TOTEM_GMP_PLUGIN
   public:
     void SetURL (const char* aURL);
+    void SetBaseURL (const char* aBaseURL);
     const char* URL() const { return mURLURI; }
 
   private:
@@ -267,6 +295,7 @@ class totemPlugin {
   public:
     bool SetQtsrc (const char* aURL);
     bool SetHref (const char* aURL);
+    void SetURL (const NPString&);
 
     const char* QtSrc () const { return mQtsrcURI; }
     const char* Href () const { return mHref; }
@@ -287,31 +316,6 @@ class totemPlugin {
     bool mAutoHref;
 #endif
 
-#if 0 //defined(TOTEM_COMPLEX_PLUGIN) && defined(HAVE_NSTARRAY_H)
-  public:
-
-    bool SetConsole (const char* aConsole);
-
-  private:
-
-    totemPlugin* FindConsoleClassRepresentant ();
-    void TransferConsole ();
-
-    void UnownedViewerSetup ();
-    void UnownedViewerSetWindow ();
-    void UnownedViewerUnsetWindow ();
-
-    totemNPObjectWrapper mPluginOwnerDocument;
-    char* mConsole;
-    char* mControls;
-
-    /* nsnull if we're the representant ourself */
-    totemPlugin *mConsoleClassRepresentant;
-
-    static nsTArray<totemPlugin*> *sPlugins;
-
-#endif /* TOTEM_COMPLEX_PLUGIN */
-
   public:
 
     enum ObjectEnum {
@@ -339,11 +343,12 @@ class totemPlugin {
     NPObject* GetNPObject (ObjectEnum which);
 
     bool SetSrc (const char* aURL);
+    bool SetSrc (const NPString& aURL);
     const char* Src() const { return mSrcURI; }
 
     void Command (const char *aCommand);
     void ClearPlaylist ();
-    int32_t AddItem (const char*);
+    int32_t AddItem (const NPString&, const NPString&, const char *aSubtitle);
 
     void SetIsWindowless (bool enabled) { mIsWindowless = enabled; }
     bool IsWindowless () const { return mIsWindowless; }
@@ -378,16 +383,16 @@ class totemPlugin {
     void SetPlayEveryFrame (bool enabled) { mPlayEveryFrame = enabled; }
     bool PlayEveryFrame () const { return mPlayEveryFrame; }
 
-    void SetBackgroundColor (const char* color);
+    void SetBackgroundColor (const NPString& color);
     const char *BackgroundColor () const { return mBackgroundColor; }
 
-    void SetMatrix (const char* matrix);
+    void SetMatrix (const NPString& matrix);
     const char* Matrix () const { return mMatrix; }
 
-    void SetRectangle (const char *rectangle);
+    void SetRectangle (const NPString& rectangle);
     const char* Rectangle () const { return mRectangle; }
 
-    void SetMovieName (const char *name);
+    void SetMovieName (const NPString& name);
     const char* MovieName () const { return mMovieName; }
 
     void SetResetPropertiesOnReload (bool enabled) { mResetPropertiesOnReload = enabled; }
@@ -396,13 +401,16 @@ class totemPlugin {
     void SetRate (double rate);
     double Rate () const;
 
+    void QueueCommand (TotemQueueCommand *cmd);
+
     double Duration () const { return double (mDuration); }
 
     int32_t BytesStreamed () const { return mBytesStreamed; }
 
     int32_t BytesLength () const { return mBytesLength; }
 
-    uint32_t Time () const { return mTime; }
+    uint64_t GetTime () const { return mTime; }
+    void SetTime (uint64_t aTime);
 
     TotemStates State () const { return mState; }
 
