@@ -105,18 +105,18 @@ static void
 totem_skipto_update_from_state (TotemObject *totem,
 				TotemSkiptoPlugin *plugin)
 {
-	gint64 time;
+	gint64 _time;
 	gboolean seekable;
 	GtkAction *action;
 	TotemSkiptoPluginPrivate *priv = plugin->priv;
 
 	g_object_get (G_OBJECT (totem),
-				"stream-length", &time,
+				"stream-length", &_time,
 				"seekable", &seekable,
 				NULL);
 
 	if (priv->st != NULL) {
-		totem_skipto_update_range (priv->st, time);
+		totem_skipto_update_range (priv->st, _time);
 		totem_skipto_set_seekable (priv->st, seekable);
 	}
 
@@ -217,8 +217,8 @@ impl_activate (TotemPlugin *plugin,
 
 	builder_path = totem_plugin_find_file (TOTEM_PLUGIN (plugin), "skipto.ui");
 	if (builder_path == NULL) {
-		g_set_error (error, TOTEM_PLUGIN_ERROR, TOTEM_PLUGIN_ERROR_ACTIVATION,
-				_("Could not load the \"Skip to\" dialog interface."));
+		g_set_error_literal (error, TOTEM_PLUGIN_ERROR, TOTEM_PLUGIN_ERROR_ACTIVATION,
+                                     _("Could not load the \"Skip to\" dialog interface."));
 		return FALSE;
 	}
 	g_free (builder_path);
