@@ -30,8 +30,13 @@
 #ifdef WITH_SMCLIENT
 
 #include <unistd.h>
+
 #include "eggsmclient.h"
 
+#ifdef GDK_WINDOWING_X11
+#include "eggdesktopfile.h"
+#endif
+
 static char *
 totem_session_create_key (void)
 {
@@ -52,7 +57,7 @@ totem_save_state_cb (EggSMClient *client,
 	             GKeyFile *key_file,
 	             Totem *totem)
 {
-	char *argv[] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL };
+	const char *argv[] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL };
 	int i = 0;
 	char *path_id, *current, *seek, *uri;
 	int current_index;
@@ -76,7 +81,7 @@ totem_save_state_cb (EggSMClient *client,
 	current = g_strdup_printf ("%d", current_index);
 	seek = g_strdup_printf ("%"G_GINT64_FORMAT,
 			bacon_video_widget_get_current_time (totem->bvw));
-	argv[i++] = (char *) totem->argv0;
+	argv[i++] = totem->argv0;
 	argv[i++] = "--playlist-idx";
 	argv[i++] = current;
 	argv[i++] = "--seek";
@@ -106,6 +111,10 @@ totem_quit_cb (EggSMClient *client,
 void
 totem_session_add_options (GOptionContext *context)
 {
+#ifdef GDK_WINDOWING_X11
+	egg_set_desktop_file_without_defaults (DATADIR "/applications/" PACKAGE ".desktop");
+#endif
+
 	g_option_context_add_group (context, egg_sm_client_get_option_group ());
 }
 
